@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # -------------------------------------------------------------------
-# Filename: seismic_attributes.py
+# Filename: seismic_attributes.py version 1.0.5
 #  Purpose: An ObsPy library for event detection and seismic attribute
 #           calculation: preparing waveforms for automated analysis.
 #   Author: Ross Turner
@@ -616,16 +616,18 @@ def __coincidence_trigger(trigger_type, thr_on, thr_off, stream, nseismometers,
         trigger_traces = event['trace_ids'] + event['trace_ids']
         trigger_sum = np.asarray([1]*len(event['time']) + [-1]*len(event['off_time']))
         index = np.argsort(trigger_times.copy())
+        
         # initialise variables
-        coincidence_sum, event['coincidence_sum'], join_time = 0, 0, None
+        coincidence_sum, event['coincidence_sum'], join_time, first_time = 0, 0, None, True
         event['stations'], event['trace_ids'] = [], []
         for i in range(0, len(index)):
             coincidence_sum = coincidence_sum + trigger_sum[index[i]]
             # coincidence sum region
             if coincidence_sum >= thr_coincidence_sum:
                 # set start time if over threshold for the first time
-                if isinstance(event['time'], list):
+                if first_time:
                     event['time'] = trigger_times[index[i]]
+                    first_time = False
                 # update end time
                 event['off_time'] = trigger_times[index[i]]
                 event['duration'] = event['off_time'] - event['time']
@@ -639,7 +641,7 @@ def __coincidence_trigger(trigger_type, thr_on, thr_off, stream, nseismometers,
                 join_time = None
             else:
                 # before coincidence sum region
-                if isinstance(event['time'], list):
+                if first_time:
                     # add station and trace_id to event catalogue and remove if it detriggers before coincidence sum region
                     if trigger_sum[index[i]] > 0:
                         event['stations'].append(trigger_stations[index[i]])
@@ -654,7 +656,7 @@ def __coincidence_trigger(trigger_type, thr_on, thr_off, stream, nseismometers,
                     event['duration'] = event['off_time'] - event['time']
                     if join_time == None:
                         join_time = event['off_time']
-                    elif (event['off_time'] - join_time) > thr_event_join or coincidence_sum < 1:
+                    elif (event['off_time'] - join_time) > thr_event_join:
                         # only join if at least one seismometer active
                         break
         # update end time and duration in case coincidence trigger did not join events
